@@ -27,6 +27,14 @@ broom::glance
 broom::augment
 
 # gtsummary --------------------------------------------------------------------
+#' @export
+#' @importFrom gtsummary tbl_regression
+gtsummary::tbl_regression
+
+#' @export
+#' @importFrom gtsummary global_pvalue_fun
+gtsummary::global_pvalue_fun
+
 #' @export
 #' @importFrom gtsummary add_n
 gtsummary::add_n
@@ -43,3 +51,4 @@ gtsummary::add_p
 #' @importFrom gtsummary inline_text
 gtsummary::inline_text
 
+
